=== modified file 'bzrlib/diff.py'
--- bzrlib/diff.py	2005-09-06 09:50:31 +0000
+++ bzrlib/diff.py	2005-09-14 09:01:06 +0000
@@ -45,14 +45,16 @@
     ud = difflib.unified_diff(oldlines, newlines,
                               fromfile=old_label, tofile=new_label)
 
+    ud = list(ud)
     # work-around for difflib being too smart for its own good
     # if /dev/null is "1,0", patch won't recognize it as /dev/null
     if not oldlines:
-        ud = list(ud)
         ud[2] = ud[2].replace('-1,0', '-0,0')
     elif not newlines:
-        ud = list(ud)
         ud[2] = ud[2].replace('+1,0', '+0,0')
+    # work around for difflib emitting random spaces after the label
+    ud[0] = ud[0][:-2] + '\n'
+    ud[1] = ud[1][:-2] + '\n'
 
     for line in ud:
         to_file.write(line)
@@ -211,7 +213,7 @@
                           specific_files=specific_files)
 
     for path, file_id, kind in delta.removed:
-        print >>to_file, '*** removed %s %r' % (kind, path)
+        print >>to_file, '=== removed %s %r' % (kind, path)
         if kind == 'file':
             diff_file(old_label + path,
                       old_tree.get_file(file_id).readlines(),
@@ -220,7 +222,7 @@
                       to_file)
 
     for path, file_id, kind in delta.added:
-        print >>to_file, '*** added %s %r' % (kind, path)
+        print >>to_file, '=== added %s %r' % (kind, path)
         if kind == 'file':
             diff_file(DEVNULL,
                       [],
@@ -229,7 +231,7 @@
                       to_file)
 
     for old_path, new_path, file_id, kind, text_modified in delta.renamed:
-        print >>to_file, '*** renamed %s %r => %r' % (kind, old_path, new_path)
+        print >>to_file, '=== renamed %s %r => %r' % (kind, old_path, new_path)
         if text_modified:
             diff_file(old_label + old_path,
                       old_tree.get_file(file_id).readlines(),
@@ -238,7 +240,7 @@
                       to_file)
 
     for path, file_id, kind in delta.modified:
-        print >>to_file, '*** modified %s %r' % (kind, path)
+        print >>to_file, '=== modified %s %r' % (kind, path)
         if kind == 'file':
             diff_file(old_label + path,
                       old_tree.get_file(file_id).readlines(),

=== modified file 'bzrlib/errors.py'
--- bzrlib/errors.py	2005-09-12 14:35:02 +0000
+++ bzrlib/errors.py	2005-09-14 09:02:54 +0000
@@ -123,6 +123,15 @@
         BzrError.__init__(self, msg)
 
 
+class NotAncestor(BzrError):
+    def __init__(self, rev_id, not_ancestor_id):
+        self.rev_id = rev_id
+        self.not_ancestor_id = not_ancestor_id
+        msg = "Revision %s is not an ancestor of %s" % (not_ancestor_id, 
+                                                        rev_id)
+        BzrError.__init__(self, msg)
+
+
 class InstallFailed(BzrError):
     def __init__(self, revisions):
         self.revisions = revisions

=== modified file 'tutorial.txt'
--- tutorial.txt	2005-09-12 14:35:02 +0000
+++ tutorial.txt	2005-09-14 09:02:54 +0000
@@ -289,8 +289,8 @@
 a copy.  Because this new copy is potentially a new branch, the
 command is called *branch*::
 
-    % bzr branch http://bazaar-ng.org/bzr/bzr.dev 
-    % cd bzr.dev
+    % bzr branch http://bazaar-ng.org/bzr/main ./bzr-main
+    % cd bzr-main
 
 This copies down the complete history of this branch, so we can
 do all operations on it locally: log, annotate, making and merging

